@@ -47,10 +47,10 @@ ci_loader_conf = {
         "branch": "BUILD_SOURCEBRANCHNAME",
         "pipeline_id": "SYSTEM_TIMELINEID",
         "job_url": {
-            "format": "{0:s}/{1:s}/_build/results?buildId={2:s}&view=logs&j={3:s}&t={4:s}",
+            "format": "{0:s}{1:s}/_build/results?buildId={2:s}&view=logs&j={3:s}&t={4:s}",
             "variables": [
                 "SYSTEM_COLLECTIONURI",
-                "BUILD_REPOSITORY_NAME",
+                "SYSTEM_TEAMPROJECT",
                 "BUILD_BUILDID",
                 "SYSTEM_JOBID",
                 "SYSTEM_TASKINSTANCEID",
