@@ -91,10 +91,10 @@ def _say_token_is_good(token_name: str):
     click.secho("You are logged into EmbedOps!\n", err=False, fg="white")
 
 
-@embedops_cli.command(hidden=True)
+@embedops_cli.command()
 @click.option("--test", "-t", help="Test your login status", is_flag=True)
 def login(test):
-    """Log into the EmbedOps platform.
+    """Log in to the EmbedOps platform.
     You will be prompted to enter your EmbedOps credentials if you are not logged in."""
     token = embedops_authorization.get_auth_token()
 
