@@ -23,7 +23,8 @@ COMPILER_PATTERN = r"IAR ANSI C/C++ Compiler (V8.50.1.245/W32) for ARM"
 #   1'036 bytes of readwrite data memory
 
 SIZE_PATTERN = (
-    r"-o\s.*?(?P<build_output_filename>[\w.]+)\s.*[\n\s]*IAR ELF(.|\n)*?"
+    r"\n(?P<target_name>[\w]+) - (?P<target_group>[\w]+)\sReading project nodes...(.|\n)*?"
+    r".*ilinkarm.*-o\s.*?(?P<build_output_filename>[\w.]+)\s.*[\n\s]*IAR ELF(.|\n)*?"
     r"(?P<flash_code_size>[\d']+).+readonly\s+code.+\n\s+"
     r"(?P<flash_data_size>[\d']+).+readonly\s+data.+\n\s+"
     r"(?P<ram_size>[\d']+).+readwrite\s+data.+"
