@@ -63,10 +63,9 @@ def parse_storage_sizes(log_filename, compiler):
         )
         storage_sizes["dimensions"] = {
             "build_target_name": result["target_name"],
-            "build_target_group": result["target_group"]
-            if "target_group" in result.groupdict()
-            else None,
         }
+        if "target_group" in result.groupdict():
+            storage_sizes["dimensions"]["build_target_group"] = result["target_group"]
         # TODO: deprecate this dimension re:eo-548
         if storage_sizes["dimensions"].get("build_target_group"):
             storage_sizes["dimensions"]["build_target"] = " - ".join(
