@@ -162,11 +162,12 @@ class TestEntrypoint:
         assert pytest_wrapped_e.type == SystemExit
         assert pytest_wrapped_e.value.code == 0
 
-        self.ci_run_caller.assert_called_with("memusage", "abcd1234", "main")
+        self.ci_run_caller.assert_called_with("memusage", "abcd1234", "main", None, None)
         self.logger_mock.info.assert_called_with(expected_id)
 
-    def test_successful_call_with_job_name(self, monkeypatch):
+    def test_successful_call_with_job_name_and_pipeline_id(self, monkeypatch):
         monkeypatch.setenv("EMBEDOPS_JOB_NAME", "build_job")
+        monkeypatch.setenv("BITBUCKET_PIPELINE_UUID", "pipe-1234")
         expected_id = "yabbazabba"
         new_ci_run = MagicMock()
         new_ci_run.id = expected_id
@@ -177,7 +178,7 @@ class TestEntrypoint:
         assert pytest_wrapped_e.value.code == 0
 
         self.ci_run_caller.assert_called_with(
-            "memusage", "abcd1234", "main", "build_job"
+            "memusage", "abcd1234", "main", "pipe-1234", "build_job"
         )
         self.logger_mock.info.assert_called_with(expected_id)
 
