@@ -139,13 +139,17 @@ def test_run_jobs_not_yaml_filename():
     )
     assert result.exit_code == 1
 
+
 def test_stale_token_prompts_login(mocker):
     """Test that a no-longer-valid auth token prompts"""
-    token_status = mocker.patch("embedops_cli.embedops_cli.embedops_authorization.check_token")
+    token_status = mocker.patch(
+        "embedops_cli.embedops_cli.embedops_authorization.check_token"
+    )
     token_status.return_value = False
 
-
-    do_login = mocker.patch("embedops_cli.embedops_cli.embedops_authorization.request_authorization")
+    do_login = mocker.patch(
+        "embedops_cli.embedops_cli.embedops_authorization.request_authorization"
+    )
     do_login.side_effect = UnauthorizedUserException()
     runner = CliRunner()
     result = runner.invoke(embedops_cli.embedops_cli, "login")
@@ -155,4 +159,4 @@ def test_stale_token_prompts_login(mocker):
 
     # mock `check user` to return false
     # verify that "do login" is called
-    # verify that if "do login" is successful that the return value is 0
\ No newline at end of file
+    # verify that if "do login" is successful that the return value is 0
